@@ -53,6 +53,7 @@ from ormar.fields import (
     Decimal,
     ENCODERS_MAP,
     EncryptBackends,
+    Enum,
     Float,
     ForeignKey,
     ForeignKeyField,
@@ -97,6 +98,7 @@ __all__ = [
     "DateTime",
     "Date",
     "Decimal",
+    "Enum",
     "Float",
     "ManyToMany",
     "Model",
