@@ -14,6 +14,7 @@ from ormar.fields.model_fields import (
     Date,
     DateTime,
     Decimal,
+    Enum,
     Float,
     Integer,
     JSON,
@@ -43,6 +44,7 @@ __all__ = [
     "Float",
     "Time",
     "UUID",
+    "Enum",
     "ForeignKey",
     "ManyToMany",
     "ManyToManyField",
