@@ -385,6 +385,22 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             )
         )
 
+    def _copy_and_set_values(
+        self: "NewBaseModel", values: "DictStrAny", fields_set: "SetStr", *, deep: bool
+    ) -> "NewBaseModel":
+        """
+        Overwrite related models values with dict representation to avoid infinite
+        recursion through related fields.
+        """
+        self_dict = values
+        self_dict.update(self.dict())
+        return cast(
+            "NewBaseModel",
+            super()._copy_and_set_values(
+                values=self_dict, fields_set=fields_set, deep=deep
+            ),
+        )
+
     @classmethod
     def get_name(cls, lower: bool = True) -> str:
         """
